ThemeVM class
- Mixed-in types
Constructors
- ThemeVM()
Properties
- darkTheme → ThemeData
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeData → ThemeData
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
saveTheme2Storage(
Brightness brightness, MaterialColor themeColor) → dynamic - 数据持久化到shared preferences
-
switchTheme(
{Brightness? brightness, MaterialColor? color, bool isInit = false, bool forciblyModify = false}) → void -
切换指定色彩
没有传
brightness就不改变brightness,color同理forciblyModify强制修改 用于初始化的时候没有适配文字大小的问题 -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultIndex ↔ int
-
getter/setter pair
Static Methods
-
iconTheme(
{Brightness? brightness, Color? color}) → IconThemeData - 可以调用后二次修改 或者自己实现
-
switchThemeBrightness(
Brightness? brightness, ThemeData? themeData) → ThemeData - 可以调用后二次修改 或者自己实现
-
textTheme(
{Brightness? brightness, Color? color}) → TextTheme - 可以调用后二次修改 或者自己实现
Constants
- kThemeBrightnessIndex → const String
- kThemeColorIndex → const String